View Source KratosPlug.Defaults (kratos_plug v0.1.0)

A collection of functions that return default values.

Link to this section Summary

Functions

Key used to store a session in Plug.Conn.assigns.

Key used to store a session in an HTTP cookie. Kratos may be configured to use any cookie name.

Key used to store a session in an HTTP header.

Headers a client may use to send a session identifier.

Link to this section Functions

Link to this function

assign_key()

View Source (since 0.1.0)
@spec assign_key() :: atom()

Key used to store a session in Plug.Conn.assigns.

Link to this function

header_key()

View Source (since 0.1.0)
@spec header_key() :: String.t()

Key used to store a session in an HTTP header.

Link to this function

header_keys()

View Source (since 0.1.0)
@spec header_keys() :: [binary()]

Headers a client may use to send a session identifier.