View Source KratosPlug.Identifiers (kratos_plug v0.1.0)

Types and functions for session identifiers. Identifiers are the client secret that may be given to kratos in return for a session.

Link to this section Summary

Functions

Returns a KratosPlug.Identifiers struct populated with conn Plug.Conn.

Returns headers from conn that kratos checks for session identifiers.

Link to this section Types

Link to this type

headers()

View Source (since 0.1.0)
@type headers() :: Plug.Conn.headers()
@type jwt() :: String.t() | map()
@type t() :: %KratosPlug.Identifiers{headers: headers() | nil, jwt: jwt() | nil}

Link to this section Functions

Link to this function

get_identifiers(conn)

View Source (since 0.1.0)
@spec get_identifiers(Plug.Conn.t()) :: Plug.Identifiers.t()

Returns a KratosPlug.Identifiers struct populated with conn Plug.Conn.

Link to this function

get_session_headers(conn)

View Source (since 0.1.0)
@spec get_session_headers(Plug.Conn.t()) :: Plug.Conn.headers()

Returns headers from conn that kratos checks for session identifiers.