View Source KratosPlug.IdentifiersMock (kratos_plug v0.1.0)
Functions for mocking KratosPlug.Identifiers.
Link to this section Summary
Functions
Returns a KratosPlug.Identifiers with a bearer token in the header.
Returns a KratosPlug.Identifiers with a cookie and session token in the header.
Returns a KratosPlug.Identifiers with a cookie in the header.
Returns a KratosPlug.Identifiers with a session token in the header.
Link to this section Functions
@spec bearer_identifier() :: KratosPlug.Identifiers.t()
Returns a KratosPlug.Identifiers with a bearer token in the header.
@spec cookie_and_token_identifier() :: KratosPlug.Identifiers.t()
Returns a KratosPlug.Identifiers with a cookie and session token in the header.
@spec cookie_identifier() :: KratosPlug.Identifiers.t()
Returns a KratosPlug.Identifiers with a cookie in the header.
@spec token_identifier() :: KratosPlug.Identifiers.t()
Returns a KratosPlug.Identifiers with a session token in the header.