View Source KratosPlug.Plugs.KratosNativePipeline (kratos_plug v0.1.0)

This pipeline is used to authenticate incoming requests using the kratos native flow. Options given to this pipeline will be passed unaltered to each of the plugs within it. Adding this pipeline to your router is the the prefered way to use KratosPlug.

plugs-in-this-pipeline

Plugs in this pipeline

This pipeline will halt if it cannot verify the incoming Kratos identity.

configuration

Configuration

See KratosPlug.Config for configuration options.