View Source KratosPlug.Plugs.KratosSession (kratos_plug v0.1.0)

Plug extracts all session identifiers from the conn request and attempts to fetch a session from kratos. When a session is found, it is assigned to the conn.

No authorization is checked, and a lack of session will not halt this plug.