View Source KratosPlug.KratosClient.TeslaAdapterMock (kratos_plug v0.1.0)
Collection of functions for mocking KratosPlug.KratosClient.TeslaAdapter.
Link to this section Summary
Functions
Returns the client options for the tesla adapter under mock.
Returns a function that can be used to mock the kratos server.
Link to this section Functions
@spec client_opts() :: Keyword.t()
Returns the client options for the tesla adapter under mock.
@spec mock_kratos() :: (... -> any())
Returns a function that can be used to mock the kratos server.
Works with Tesla.Mock.mock/1
request-shapes
Request shapes
- Only have a cookie
- Only have a token
- Have both a cookie and a token
- Have neither a cookie nor a token